Data
-------

Datasets
^^^^^^^^^^^^^^^^
*data()*
"""""""""""""""""
.. autofunction:: neurokit2.data.data


I/O
^^^^^^^^^^^^^^^^
*read_acqknowledge()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.data.read_acqknowledge

*read_bitalino()*
""""""""""""""""""
.. autofunction:: neurokit2.data.read_bitalino

*read_video()*
""""""""""""""""""
.. autofunction:: neurokit2.data.read_video

*write_csv()*
"""""""""""""""
.. autofunction:: neurokit2.data.write_csv

*Other*
^^^^^^^^^

.. automodule:: neurokit2.data
   :members:
   :exclude-members: data, read_acqknowledge, read_bitalino, write_csv, read_video